@@ -3,7 +3,7 @@
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -23,12 +23,13 @@
  * terms and conditions of either the GPL or the CDDL or both.
  */
 
-#ifndef ___iprt_asm_h
+#ifndef IPRT_INCLUDED_asm_watcom_x86_16_h
+#define IPRT_INCLUDED_asm_watcom_x86_16_h
+/* no pragma once */
+
+#ifndef IPRT_INCLUDED_asm_h
 # error "Don't include this header directly."
 #endif
-#ifndef ___iprt_asm_watcom_x86_16_h
-#define ___iprt_asm_watcom_x86_16_h
-
 
 /*
  * Turns out we cannot use 'ds' for segment stuff here because the compiler
@@ -38,46 +39,54 @@
  * Note! The #undef that preceds the #pragma aux statements is for undoing
  *       the mangling, because the symbol in #pragma aux [symbol] statements
  *       doesn't get subjected to preprocessing.  This is also why we include
- *       the watcom header at the top rather than at the bottom of the
- *       asm-amd64-x86.h file.
+ *       the watcom header at both the top and the bottom of asm.h file.
  */
 
 #undef       ASMCompilerBarrier
-#if 0 /* overkill version. */
-# pragma aux ASMCompilerBarrier = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if 0 /* overkill version. */
+#  pragma aux ASMCompilerBarrier = \
     "nop" \
     parm [] \
     modify exact [ax bx cx dx es ds];
-#else
-# pragma aux ASMCompilerBarrier = \
+# else
+#  pragma aux ASMCompilerBarrier = \
     "" \
     parm [] \
     modify exact [];
+# endif
 #endif
 
 #undef      ASMNopPause
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMNopPause = \
     ".686p" \
     ".xmm2" \
     "pause" \
     parm [] nomemory \
     modify exact [] nomemory;
+#endif
 
 #undef      ASMAtomicXchgU8
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicXchgU8 = \
     "xchg es:[bx], al" \
     parm [es bx] [al] \
     value [al] \
     modify exact [al];
+#endif
 
 #undef      ASMAtomicXchgU16
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicXchgU16 = \
     "xchg es:[bx], ax" \
     parm [es bx] [ax] \
     value [ax] \
     modify exact [ax];
+#endif
 
 #undef      ASMAtomicXchgU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicXchgU32 = \
     ".386" \
     "shl  ecx, 16" \
@@ -88,8 +97,10 @@
     parm [es bx] [ax cx] \
     value [ax cx] \
     modify exact [ax cx];
+#endif
 
 #undef      ASMAtomicXchgU64
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicXchgU64 = \
     ".586" \
     "shl eax, 16" \
@@ -109,8 +120,10 @@
     parm [es si] [dx cx bx ax] \
     value [dx cx bx ax] \
     modify exact [dx cx bx ax];
+#endif
 
 #undef      ASMAtomicCmpXchgU8
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicCmpXchgU8 = \
     ".486" \
     "lock cmpxchg es:[bx], cl" \
@@ -118,8 +131,10 @@
     parm [es bx] [cl] [al] \
     value [al] \
     modify exact [al];
+#endif
 
 #undef      ASMAtomicCmpXchgU16
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicCmpXchgU16 = \
     ".486" \
     "lock cmpxchg es:[bx], cx" \
@@ -127,8 +142,10 @@
     parm [es bx] [cx] [ax] \
     value [al] \
     modify exact [ax];
+#endif
 
 #undef      ASMAtomicCmpXchgU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicCmpXchgU32 = \
     ".486" \
     "shl ecx, 16" \
@@ -141,20 +158,24 @@
     parm [es bx] [cx dx] [ax di] \
     value [al] \
     modify exact [ax cx];
+#endif
 
 /* ASMAtomicCmpXchgU64: External assembly implementation, too few registers for parameters.  */
 /* ASMAtomicCmpXchgExU32: External assembly implementation, too few registers for parameters.  */
 /* ASMAtomicCmpXchgExU64: External assembly implementation, too few registers for parameters.  */
 
 #undef      ASMSerializeInstructionCpuId
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMSerializeInstructionCpuId = \
     ".586" \
     "xor eax, eax" \
     "cpuid" \
     parm [] \
     modify exact [ax bx cx dx];
+#endif
 
 #undef ASMSerializeInstructionIRet
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMSerializeInstructionIRet = \
     "pushf" \
     "push cs" \
@@ -165,14 +186,18 @@
     "done:" \
     parm [] \
     modify exact [];
+#endif
 
 #undef      ASMSerializeInstructionRdTscp
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMSerializeInstructionRdTscp = \
     0x0f 0x01 0xf9 \
     parm [] \
     modify exact [ax dx cx];
+#endif
 
 #undef      ASMAtomicReadU64
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicReadU64 = \
     ".586" \
     "xor eax, eax" \
@@ -188,8 +213,10 @@
     parm [es si] \
     value [dx cx bx ax] \
     modify exact [dx cx bx ax];
+#endif
 
 #undef      ASMAtomicUoReadU64
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicUoReadU64 = \
     ".586" \
     "xor eax, eax" \
@@ -205,16 +232,20 @@
     parm [es si] \
     value [dx cx bx ax] \
     modify exact [dx cx bx ax];
+#endif
 
 #undef      ASMAtomicAddU16
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicAddU16 = \
     ".486" \
     "lock xadd es:[bx], ax" \
     parm [es bx] [ax] \
     value [ax] \
     modify exact [ax];
+#endif
 
 #undef      ASMAtomicAddU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicAddU32 = \
     ".486" \
     "shl edx, 16" \
@@ -225,8 +256,10 @@
     parm [es bx] [ax dx] \
     value [ax dx] \
     modify exact [ax dx];
+#endif
 
 #undef      ASMAtomicIncU16
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicIncU16 = \
     ".486" \
     "mov ax, 1" \
@@ -235,8 +268,10 @@
     parm [es bx] \
     value [ax] \
     modify exact [ax];
+#endif
 
 #undef      ASMAtomicIncU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicIncU32 = \
     ".486" \
     "mov edx, 1" \
@@ -247,10 +282,12 @@
     parm [es bx] \
     value [ax dx] \
     modify exact [ax dx];
+#endif
 
 /* ASMAtomicIncU64: Should be done by C inline or in external file. */
 
 #undef      ASMAtomicDecU16
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicDecU16 = \
     ".486" \
     "mov ax, 0ffffh" \
@@ -259,8 +296,10 @@
     parm [es bx] \
     value [ax] \
     modify exact [ax];
+#endif
 
 #undef      ASMAtomicDecU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicDecU32 = \
     ".486" \
     "mov edx, 0ffffffffh" \
@@ -271,10 +310,12 @@
     parm [es bx] \
     value [ax dx] \
     modify exact [ax dx];
+#endif
 
 /* ASMAtomicDecU64: Should be done by C inline or in external file. */
 
 #undef      ASMAtomicOrU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicOrU32 = \
     ".386" \
     "shl edx, 16" \
@@ -282,10 +323,12 @@
     "lock or es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+#endif
 
 /* ASMAtomicOrU64: Should be done by C inline or in external file. */
 
 #undef      ASMAtomicAndU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicAndU32 = \
     ".386" \
     "shl edx, 16" \
@@ -293,10 +336,12 @@
     "lock and es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+#endif
 
 /* ASMAtomicAndU64: Should be done by C inline or in external file. */
 
 #undef      ASMAtomicUoOrU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicUoOrU32 = \
     ".386" \
     "shl edx, 16" \
@@ -304,10 +349,12 @@
     "or es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+#endif
 
 /* ASMAtomicUoOrU64: Should be done by C inline or in external file. */
 
 #undef      ASMAtomicUoAndU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicUoAndU32 = \
     ".386" \
     "shl edx, 16" \
@@ -315,10 +362,12 @@
     "and es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+#endif
 
 /* ASMAtomicUoAndU64: Should be done by C inline or in external file. */
 
 #undef      ASMAtomicUoIncU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicUoIncU32 = \
     ".486" \
     "mov edx, 1" \
@@ -329,8 +378,10 @@
     parm [es bx] \
     value [ax dx] \
     modify exact [ax dx];
+#endif
 
 #undef      ASMAtomicUoDecU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicUoDecU32 = \
     ".486" \
     "mov edx, 0ffffffffh" \
@@ -341,46 +392,52 @@
     parm [es bx] \
     value [ax dx] \
     modify exact [ax dx];
+#endif
 
 #undef      ASMMemZeroPage
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMMemZeroPage = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMMemZeroPage = \
     "mov cx, 2048" \
     "xor ax, ax" \
     "rep stosw"  \
     parm [es di] \
     modify exact [ax cx di];
-#else
-# pragma aux ASMMemZeroPage = \
+# else
+#  pragma aux ASMMemZeroPage = \
     "mov ecx, 1024" \
     "xor eax, eax" \
     "rep stosd"  \
     parm [es di] \
     modify exact [ax cx di];
+# endif
 #endif
 
 #undef      ASMMemZero32
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMMemZero32 = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMMemZero32 = \
     "xor ax, ax" \
     "shr cx, 1" \
     "shr cx, 1" \
     "rep stosw" \
     parm [es di] [cx] \
     modify exact [ax dx cx di];
-#else
-# pragma aux ASMMemZero32 = \
+# else
+#  pragma aux ASMMemZero32 = \
     "and ecx, 0ffffh" /* probably not necessary, lazy bird should check... */ \
     "shr ecx, 2" \
     "xor eax, eax" \
     "rep stosd"  \
     parm [es di] [cx] \
     modify exact [ax cx di];
+# endif
 #endif
 
 #undef      ASMMemFill32
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMMemFill32 = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMMemFill32 = \
     "   shr     cx, 1" \
     "   shr     cx, 1" \
     "   jz      done" \
@@ -394,8 +451,8 @@
     "done:" \
     parm [es di] [cx] [ax dx]\
     modify exact [cx di];
-#else
-# pragma aux ASMMemFill32 = \
+# else
+#  pragma aux ASMMemFill32 = \
     "and ecx, 0ffffh" /* probably not necessary, lazy bird should check... */ \
     "shr ecx, 2" \
     "shl eax, 16" \
@@ -404,18 +461,22 @@
     "rep stosd"  \
     parm [es di] [cx] [ax dx]\
     modify exact [ax cx di];
+# endif
 #endif
 
 #undef      ASMProbeReadByte
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMProbeReadByte = \
     "mov al, es:[bx]" \
     parm [es bx] \
     value [al] \
     modify exact [al];
+#endif
 
 #undef      ASMBitSet
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMBitSet = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMBitSet = \
     "   mov     ch, cl" /* Only the three lowest bits are relevant due to 64KB segments */ \
     "   mov     cl, 5" \
     "   shl     ch, cl" \
@@ -431,16 +492,18 @@
     "   or      es:[bx], al" \
     parm [es bx] [ax cx] \
     modify exact [ax bx cx];
-#else
-# pragma aux ASMBitSet = \
+# else
+#  pragma aux ASMBitSet = \
     "shl edx, 16" \
     "mov dx, ax" \
     "bts es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+# endif
 #endif
 
 #undef      ASMAtomicBitSet
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicBitSet = \
     ".386" \
     "shl edx, 16" \
@@ -448,10 +511,12 @@
     "lock bts es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+#endif
 
 #undef      ASMBitClear
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMBitClear = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMBitClear = \
     "   mov     ch, cl" /* Only the three lowest bits are relevant due to 64KB segments */ \
     "   mov     cl, 5" \
     "   shl     ch, cl" \
@@ -468,16 +533,18 @@
     "   and     es:[bx], al" \
     parm [es bx] [ax cx] \
     modify exact [ax bx cx];
-#else
-# pragma aux ASMBitClear = \
+# else
+#  pragma aux ASMBitClear = \
     "shl edx, 16" \
     "mov dx, ax" \
     "btr es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+# endif
 #endif
 
 #undef      ASMAtomicBitClear
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicBitClear = \
     ".386" \
     "shl edx, 16" \
@@ -485,10 +552,12 @@
     "lock btr es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+#endif
 
 #undef      ASMBitToggle
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMBitToggle = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMBitToggle = \
     "   mov     ch, cl" /* Only the three lowest bits are relevant due to 64KB segments */ \
     "   mov     cl, 5" \
     "   shl     ch, cl" \
@@ -504,16 +573,18 @@
     "   xor     es:[bx], al" \
     parm [es bx] [ax cx] \
     modify exact [ax bx cx];
-#else
-# pragma aux ASMBitToggle = \
+# else
+#  pragma aux ASMBitToggle = \
     "shl edx, 16" \
     "mov dx, ax" \
     "btc es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+# endif
 #endif
 
 #undef      ASMAtomicBitToggle
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicBitToggle = \
     ".386" \
     "shl edx, 16" \
@@ -521,10 +592,12 @@
     "lock btc es:[bx], edx" \
     parm [es bx] [ax dx] \
     modify exact [dx];
+#endif
 
 #undef      ASMBitTestAndSet
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMBitTestAndSet = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMBitTestAndSet = \
     "   mov     ch, cl" /* Only the three lowest bits are relevant due to 64KB segments */ \
     "   mov     cl, 5" \
     "   shl     ch, cl" \
@@ -545,8 +618,8 @@
     parm [es bx] [ax cx] \
     value [al] \
     modify exact [ax bx cx];
-#else
-# pragma aux ASMBitTestAndSet = \
+# else
+#  pragma aux ASMBitTestAndSet = \
     "shl edx, 16" \
     "mov dx, ax" \
     "bts es:[bx], edx" \
@@ -554,9 +627,11 @@
     parm [es bx] [ax dx] \
     value [al] \
     modify exact [ax dx];
+# endif
 #endif
 
 #undef      ASMAtomicBitTestAndSet
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicBitTestAndSet = \
     ".386" \
     "shl edx, 16" \
@@ -566,10 +641,12 @@
     parm [es bx] [ax dx] \
     value [al] \
     modify exact [ax dx];
+#endif
 
 #undef      ASMBitTestAndClear
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMBitTestAndClear = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMBitTestAndClear = \
     "   mov     ch, cl" /* Only the three lowest bits are relevant due to 64KB segments */ \
     "   mov     cl, 5" \
     "   shl     ch, cl" \
@@ -591,8 +668,8 @@
     parm [es bx] [ax cx] \
     value [al] \
     modify exact [ax bx cx];
-#else
-# pragma aux ASMBitTestAndClear = \
+# else
+#  pragma aux ASMBitTestAndClear = \
     "shl edx, 16" \
     "mov dx, ax" \
     "btr es:[bx], edx" \
@@ -600,9 +677,11 @@
     parm [es bx] [ax dx] \
     value [al] \
     modify exact [ax dx];
+# endif
 #endif
 
 #undef      ASMAtomicBitTestAndClear
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicBitTestAndClear = \
     ".386" \
     "shl edx, 16" \
@@ -612,10 +691,12 @@
     parm [es bx] [ax dx] \
     value [al] \
     modify exact [ax dx];
+#endif
 
 #undef      ASMBitTestAndToggle
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMBitTestAndToggle = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMBitTestAndToggle = \
     "   mov     ch, cl" /* Only the three lowest bits are relevant due to 64KB segments */ \
     "   mov     cl, 5" \
     "   shl     ch, cl" \
@@ -636,8 +717,8 @@
     parm [es bx] [ax cx] \
     value [al] \
     modify exact [ax bx cx];
-#else
-# pragma aux ASMBitTestAndToggle = \
+# else
+#  pragma aux ASMBitTestAndToggle = \
     "shl edx, 16" \
     "mov dx, ax" \
     "btc es:[bx], edx" \
@@ -645,9 +726,11 @@
     parm [es bx] [ax dx] \
     value [al] \
     modify exact [ax dx];
+# endif
 #endif
 
 #undef      ASMAtomicBitTestAndToggle
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMAtomicBitTestAndToggle = \
     ".386" \
     "shl edx, 16" \
@@ -657,10 +740,12 @@
     parm [es bx] [ax dx] \
     value [al] \
     modify exact [ax dx];
+#endif
 
 #undef      ASMBitTest
-#if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
-# pragma aux ASMBitTest = \
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
+# if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
+#  pragma aux ASMBitTest = \
     "   mov     ch, cl" /* Only the three lowest bits are relevant due to 64KB segments */ \
     "   mov     cl, 5" \
     "   shl     ch, cl" \
@@ -677,8 +762,8 @@
     parm [es bx] [ax cx] \
     value [al] \
     modify exact [ax bx cx];
-#else
-# pragma aux ASMBitTest = \
+# else
+#  pragma aux ASMBitTest = \
     "shl edx, 16" \
     "mov dx, ax" \
     "bt  es:[bx], edx" \
@@ -686,6 +771,7 @@
     parm [es bx] [ax dx] nomemory \
     value [al] \
     modify exact [ax dx] nomemory;
+# endif
 #endif
 
 /* ASMBitFirstClear: External file.  */
@@ -697,6 +783,7 @@
 /* ASMBitFirstSetU32: External file. */
 #else
 # undef      ASMBitFirstSetU32
+# ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 # pragma aux ASMBitFirstSetU32 = \
     "shl edx, 16" \
     "mov dx, ax" \
@@ -710,12 +797,14 @@
     parm [ax dx] nomemory \
     value [ax] \
     modify exact [ax dx] nomemory;
+# endif
 #endif
 
 #if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
 /* ASMBitFirstSetU64: External file. */
 #else
 # undef      ASMBitFirstSetU64
+# ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 # pragma aux ASMBitFirstSetU64 = \
     ".386" \
     "shl ecx, 16" \
@@ -740,12 +829,14 @@
     parm [dx cx bx ax] nomemory \
     value [ax] \
     modify exact [ax cx] nomemory;
+# endif
 #endif
 
 #if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
 /* ASMBitFirstSetU16: External file. */
 #else
 # undef      ASMBitFirstSetU16
+# ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 # pragma aux ASMBitFirstSetU16 = \
     "bsf ax, ax" \
     "jz  not_found" \
@@ -757,12 +848,14 @@
     parm [ax] nomemory \
     value [ax] \
     modify exact [ax] nomemory;
+# endif
 #endif
 
 #if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
 /* ASMBitLastSetU32: External file. */
 #else
 # undef      ASMBitLastSetU32
+# ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 # pragma aux ASMBitLastSetU32 = \
     "shl edx, 16" \
     "mov dx, ax" \
@@ -776,12 +869,14 @@
     parm [ax dx] nomemory \
     value [ax] \
     modify exact [ax dx] nomemory;
+# endif
 #endif
 
 #if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
 /* ASMBitLastSetU64: External file. */
 #else
 # undef      ASMBitLastSetU64
+# ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 # pragma aux ASMBitLastSetU64 = \
     ".386" \
     "shl ecx, 16" \
@@ -806,12 +901,14 @@
     parm [dx cx bx ax] nomemory \
     value [ax] \
     modify exact [ax cx] nomemory;
+# endif
 #endif
 
 #if defined(__SW_0) || defined(__SW_1) || defined(__SW_2)
 /* ASMBitLastSetU16: External file. */
 #else
 # undef      ASMBitLastSetU16
+# ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 # pragma aux ASMBitLastSetU16 = \
     "bsr ax, ax" \
     "jz  not_found" \
@@ -823,24 +920,30 @@
     parm [ax] nomemory \
     value [ax] \
     modify exact [ax] nomemory;
+# endif
 #endif
 
 #undef      ASMByteSwapU16
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMByteSwapU16 = \
     "xchg al, ah" \
     parm [ax] nomemory \
     value [ax] \
     modify exact [ax] nomemory;
+#endif
 
 #undef      ASMByteSwapU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMByteSwapU32 = \
     "xchg dh, al" \
     "xchg dl, ah" \
     parm [ax dx] nomemory \
     value [ax dx] \
     modify exact [ax dx] nomemory;
+#endif
 
 #undef      ASMRotateLeftU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMRotateLeftU32 = \
     ".386" \
     "shl    edx, 16" \
@@ -851,8 +954,10 @@
     parm [ax dx] [cx] nomemory \
     value [ax dx] \
     modify exact [ax dx] nomemory;
+#endif
 
 #undef      ASMRotateRightU32
+#ifdef IPRT_ASM_WATCOM_X86_16_WITH_PRAGMAS
 #pragma aux ASMRotateRightU32 = \
     ".386" \
     "shl    edx, 16" \
@@ -863,5 +968,6 @@
     parm [ax dx] [cx] nomemory \
     value [ax dx] \
     modify exact [ax dx] nomemory;
-
 #endif
+
+#endif /* !IPRT_INCLUDED_asm_watcom_x86_16_h */
