@@ -3,7 +3,7 @@
  */
 
 /*
- * Copyright (C) 2006-2015 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -39,8 +39,11 @@
  * ====================================================
  */
 
-#ifndef ___iprt_nocrt_math_h
-#define ___iprt_nocrt_math_h
+#ifndef IPRT_INCLUDED_nocrt_math_h
+#define IPRT_INCLUDED_nocrt_math_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 #if !defined(__GNUC__) /* && !defined(__YOUR_COMPILER__) */
 # error "IPRT: Adjust this header for your compiler"
@@ -56,6 +59,7 @@
 #else
 #define __GNUC_PREREQ__(ma, mi) 0
 #endif
+#undef  __pure2 /* darwin: avoid conflict with system headers when doing syntax checking of the headers */
 #define __pure2
 
 
@@ -819,5 +823,5 @@ RT_C_DECLS_END
 # include <iprt/nocrt/x86/math.h>
 #endif
 
-#endif
+#endif /* !IPRT_INCLUDED_nocrt_math_h */
 
