@@ -53,8 +53,9 @@
 *   Class UIWizardExportAppPage2 implementation.                                                                                 *
 *********************************************************************************************************************************/
 
-UIWizardExportAppPage2::UIWizardExportAppPage2()
-    : m_pFormatLayout(0)
+UIWizardExportAppPage2::UIWizardExportAppPage2(bool fExportToOCIByDefault)
+    : m_fExportToOCIByDefault(fExportToOCIByDefault)
+    , m_pFormatLayout(0)
     , m_pSettingsLayout1(0)
     , m_pSettingsLayout2(0)
     , m_pFormatComboBoxLabel(0)
@@ -92,6 +93,7 @@ void UIWizardExportAppPage2::populateFormats()
     }
 
     /* Initialize Cloud Provider Manager: */
+    bool fOCIPresent = false;
     CVirtualBox comVBox = vboxGlobal().virtualBox();
     m_comCloudProviderManager = comVBox.GetCloudProviderManager();
     /* Show error message if necessary: */
@@ -119,12 +121,17 @@ void UIWizardExportAppPage2::populateFormats()
                 m_pFormatComboBox->setItemData(m_pFormatComboBox->count() - 1, comProvider.GetName(),      FormatData_Name);
                 m_pFormatComboBox->setItemData(m_pFormatComboBox->count() - 1, comProvider.GetShortName(), FormatData_ShortName);
                 m_pFormatComboBox->setItemData(m_pFormatComboBox->count() - 1, true,                       FormatData_IsItCloudFormat);
+                if (m_pFormatComboBox->itemData(m_pFormatComboBox->count() - 1, FormatData_ShortName).toString() == "OCI")
+                    fOCIPresent = true;
             }
         }
     }
 
     /* Set default: */
-    setFormat("ovf-1.0");
+    if (m_fExportToOCIByDefault && fOCIPresent)
+        setFormat("OCI");
+    else
+        setFormat("ovf-1.0");
 }
 
 void UIWizardExportAppPage2::populateMACAddressPolicies()
@@ -511,6 +518,9 @@ void UIWizardExportAppPage2::refreshFileSelectorName()
 
 void UIWizardExportAppPage2::refreshFileSelectorExtension()
 {
+    /* Save old extension to compare afterwards: */
+    const QString strOldExtension = m_strFileSelectorExt;
+
     /* If format is cloud one: */
     if (isFormatCloudOne())
     {
@@ -531,19 +541,27 @@ void UIWizardExportAppPage2::refreshFileSelectorExtension()
                                         UIWizardExportApp::tr("Open Virtualization Format (%1)").arg("*.ovf"));
     }
 
-    /* Cascade update for file selector path: */
-    refreshFileSelectorPath();
+    /* Cascade update for file selector path if necessary: */
+    if (m_strFileSelectorExt != strOldExtension)
+        refreshFileSelectorPath();
 }
 
 void UIWizardExportAppPage2::refreshFileSelectorPath()
 {
-    /* Compose file selector path: */
-    const QString strPath = QDir::toNativeSeparators(QString("%1/%2")
-                                                     .arg(vboxGlobal().documentsPath())
-                                                     .arg(m_strFileSelectorName + m_strFileSelectorExt));
-
-    /* Assign the path: */
-    m_pFileSelector->setPath(strPath);
+    /* If format is cloud one: */
+    if (isFormatCloudOne())
+    {
+        /* Clear file selector path: */
+        m_pFileSelector->setPath(QString());
+    }
+    else
+    {
+        /* Compose file selector path: */
+        const QString strPath = QDir::toNativeSeparators(QString("%1/%2")
+                                                         .arg(vboxGlobal().documentsPath())
+                                                         .arg(m_strFileSelectorName + m_strFileSelectorExt));
+        m_pFileSelector->setPath(strPath);
+    }
 }
 
 void UIWizardExportAppPage2::refreshManifestCheckBoxAccess()
@@ -732,8 +750,9 @@ AbstractVSDParameterList UIWizardExportAppPage2::cloudClientParameters() const
 *   Class UIWizardExportAppPageBasic2 implementation.                                                                            *
 *********************************************************************************************************************************/
 
-UIWizardExportAppPageBasic2::UIWizardExportAppPageBasic2()
-    : m_pLabelFormat(0)
+UIWizardExportAppPageBasic2::UIWizardExportAppPageBasic2(bool fExportToOCIByDefault)
+    : UIWizardExportAppPage2(fExportToOCIByDefault)
+    , m_pLabelFormat(0)
     , m_pLabelSettings(0)
 {
     /* Create main layout: */
@@ -993,7 +1012,8 @@ UIWizardExportAppPageBasic2::UIWizardExportAppPageBasic2()
     if (gpManager)
         connect(gpManager, &UIVirtualBoxManager::sigCloudProfileManagerChange,
                 this, &UIWizardExportAppPageBasic2::sltHandleFormatComboChange);
-    connect(m_pFileSelector, &UIEmptyFilePathSelector::pathChanged, this, &UIWizardExportAppPageBasic2::completeChanged);
+    connect(m_pFileSelector, &UIEmptyFilePathSelector::pathChanged,
+            this, &UIWizardExportAppPageBasic2::sltHandleFileSelectorChange);
     connect(m_pFormatComboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
             this, &UIWizardExportAppPageBasic2::sltHandleFormatComboChange);
     connect(m_pMACComboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
@@ -1136,7 +1156,7 @@ void UIWizardExportAppPageBasic2::initializePage()
     retranslateUi();
 
     /* Refresh file selector name: */
-    // refreshFileSelectorName(); alreeady called from retranslateUi();
+    // refreshFileSelectorName(); already called from retranslateUi();
     /* Refresh file selector extension: */
     refreshFileSelectorExtension();
     /* Refresh manifest check-box access: */
@@ -1227,6 +1247,16 @@ void UIWizardExportAppPageBasic2::sltHandleFormatComboChange()
     emit completeChanged();
 }
 
+void UIWizardExportAppPageBasic2::sltHandleFileSelectorChange()
+{
+    /* Remember changed name, except empty one: */
+    if (!m_pFileSelector->path().isEmpty())
+        m_strFileSelectorName = QFileInfo(m_pFileSelector->path()).completeBaseName();
+
+    /* Refresh required settings: */
+    emit completeChanged();
+}
+
 void UIWizardExportAppPageBasic2::sltHandleMACAddressPolicyComboChange()
 {
     /* Update tool-tip: */
