@@ -45,8 +45,9 @@
 *   Class UIWizardExportAppPageExpert implementation.                                                                            *
 *********************************************************************************************************************************/
 
-UIWizardExportAppPageExpert::UIWizardExportAppPageExpert(const QStringList &selectedVMNames)
-    : m_pSelectorCnt(0)
+UIWizardExportAppPageExpert::UIWizardExportAppPageExpert(const QStringList &selectedVMNames, bool fExportToOCIByDefault)
+    : UIWizardExportAppPage2(fExportToOCIByDefault)
+    , m_pSelectorCnt(0)
     , m_pApplianceCnt(0)
     , m_pSettingsCnt(0)
 {
@@ -353,7 +354,8 @@ UIWizardExportAppPageExpert::UIWizardExportAppPageExpert(const QStringList &sele
         connect(gpManager, &UIVirtualBoxManager::sigCloudProfileManagerChange,
                 this, &UIWizardExportAppPageExpert::sltHandleFormatComboChange);
     connect(m_pVMSelector, &QListWidget::itemSelectionChanged,      this, &UIWizardExportAppPageExpert::sltVMSelectionChangeHandler);
-    connect(m_pFileSelector, &UIEmptyFilePathSelector::pathChanged, this, &UIWizardExportAppPageExpert::completeChanged);
+    connect(m_pFileSelector, &UIEmptyFilePathSelector::pathChanged,
+            this, &UIWizardExportAppPageExpert::sltHandleFileSelectorChange);
     connect(m_pFormatComboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
             this, &UIWizardExportAppPageExpert::sltHandleFormatComboChange);
     connect(m_pMACComboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
@@ -582,6 +584,16 @@ void UIWizardExportAppPageExpert::sltHandleFormatComboChange()
     emit completeChanged();
 }
 
+void UIWizardExportAppPageExpert::sltHandleFileSelectorChange()
+{
+    /* Remember changed name, except empty one: */
+    if (!m_pFileSelector->path().isEmpty())
+        m_strFileSelectorName = QFileInfo(m_pFileSelector->path()).completeBaseName();
+
+    /* Refresh required settings: */
+    emit completeChanged();
+}
+
 void UIWizardExportAppPageExpert::sltHandleMACAddressPolicyComboChange()
 {
     /* Update tool-tip: */
