@@ -96,6 +96,8 @@ static void vbsfPathResolveRelative(char *pszPathBegin)
 int vbsfPathAbs(const char *pszRoot, const char *pszPath, char *pszAbsPath, size_t cbAbsPath)
 {
 #if defined(RT_OS_WINDOWS)
+    /** @todo This code is not needed in 6.0 and later as IPRT translates paths
+     *        to \\.\ format if they're too long.  */
     const char *pszPathStart = pszRoot? pszRoot: pszPath;
 
     /* Windows extended-length paths. */
@@ -181,5 +183,8 @@ int vbsfPathAbs(const char *pszRoot, const char *pszPath, char *pszAbsPath, size
 #endif /* RT_OS_WINDOWS */
 
     /* Fallback for the common paths. */
-    return RTPathAbsEx(pszRoot, pszPath, pszAbsPath, cbAbsPath);
+
+    if (*pszPath != '\0')
+        return RTPathAbsEx(pszRoot, pszPath, RTPATH_STR_F_STYLE_HOST, pszAbsPath, &cbAbsPath);
+    return RTPathAbsEx(NULL, pszRoot, RTPATH_STR_F_STYLE_HOST, pszAbsPath, &cbAbsPath);
 }
