@@ -1,12 +1,10 @@
 /* $Id: AutoCaller.cpp $ */
-
 /** @file
- *
  * VirtualBox object state implementation
  */
 
 /*
- * Copyright (C) 2006-2016 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -17,11 +15,12 @@
  * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
  */
 
+#define LOG_GROUP LOG_GROUP_MAIN
 #include <iprt/semaphore.h>
 
 #include "VirtualBoxBase.h"
 #include "AutoCaller.h"
-#include "Logging.h"
+#include "LoggingNew.h"
 
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -312,7 +311,7 @@ void ObjectState::autoInitSpanDestructor(State aNewState, HRESULT aFailedRC, com
     setState(aNewState);
 }
 
-ObjectState::State ObjectState::autoUninitSpanConstructor()
+ObjectState::State ObjectState::autoUninitSpanConstructor(bool fTry)
 {
     AutoWriteLock stateLock(mStateLock COMMA_LOCKVAL_SRC_POS);
 
@@ -329,6 +328,9 @@ ObjectState::State ObjectState::autoUninitSpanConstructor()
          * completion. This is necessary to make sure that when this method
          * returns, the object state is well-defined (NotReady). */
 
+        if (fTry)
+            return Ready;
+
         /* lazy semaphore creation */
         if (mInitUninitSem == NIL_RTSEMEVENTMULTI)
         {
@@ -360,6 +362,9 @@ ObjectState::State ObjectState::autoUninitSpanConstructor()
     /* wait for already existing callers to drop to zero */
     if (mCallers > 0)
     {
+        if (fTry)
+            return Ready;
+
         /* lazy creation */
         Assert(mZeroCallersSem == NIL_RTSEMEVENT);
         RTSemEventCreate(&mZeroCallersSem);
@@ -517,19 +522,24 @@ AutoReinitSpan::~AutoReinitSpan()
  *
  * @param aObj  |this| pointer of the VirtualBoxBase object whose uninit()
  *              method is being called.
+ * @param fTry  @c true if the wait for other callers should be skipped,
+ *              requiring checking if the uninit span is actually operational.
  */
-AutoUninitSpan::AutoUninitSpan(VirtualBoxBase *aObj)
+AutoUninitSpan::AutoUninitSpan(VirtualBoxBase *aObj, bool fTry /* = false */)
     : mObj(aObj),
       mInitFailed(false),
-      mUninitDone(false)
+      mUninitDone(false),
+      mUninitFailed(false)
 {
     Assert(mObj);
     ObjectState::State state;
-    state = mObj->getObjectState().autoUninitSpanConstructor();
+    state = mObj->getObjectState().autoUninitSpanConstructor(fTry);
     if (state == ObjectState::InitFailed)
         mInitFailed = true;
     else if (state == ObjectState::NotReady)
         mUninitDone = true;
+    else if (state == ObjectState::Ready)
+        mUninitFailed = true;
 }
 
 /**
@@ -538,7 +548,7 @@ AutoUninitSpan::AutoUninitSpan(VirtualBoxBase *aObj)
 AutoUninitSpan::~AutoUninitSpan()
 {
     /* do nothing if already uninitialized */
-    if (mUninitDone)
+    if (mUninitDone || mUninitFailed)
         return;
 
     mObj->getObjectState().autoUninitSpanDestructor();
@@ -552,7 +562,7 @@ AutoUninitSpan::~AutoUninitSpan()
 void AutoUninitSpan::setSucceeded()
 {
     /* do nothing if already uninitialized */
-    if (mUninitDone)
+    if (mUninitDone || mUninitFailed)
         return;
 
     mObj->getObjectState().autoUninitSpanDestructor();
