@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2009-2017 Oracle Corporation
+ * Copyright (C) 2009-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -68,6 +68,12 @@ int NetworkServiceRunner::setOption(const std::string& key, const std::string& v
 }
 
 
+void NetworkServiceRunner::clearOptions()
+{
+    m->mOptions.clear();
+}
+
+
 void NetworkServiceRunner::detachFromServer()
 {
     m->mProcess = NIL_RTPROCESS;
