@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2009-2016 Oracle Corporation
+ * Copyright (C) 2009-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -688,9 +688,21 @@ VBoxNetLwipNAT::VBoxNetLwipNAT(SOCKET icmpsock4, SOCKET icmpsock6) : VBoxNetBase
 
 VBoxNetLwipNAT::~VBoxNetLwipNAT()
 {
-    if (m_ProxyOptions.tftp_root != NULL)
+    if (m_ProxyOptions.tftp_root)
     {
         RTStrFree((char *)m_ProxyOptions.tftp_root);
+        m_ProxyOptions.tftp_root = NULL;
+    }
+    if (m_ProxyOptions.nameservers)
+    {
+        const char **pv = m_ProxyOptions.nameservers;
+        while (*pv)
+        {
+            RTStrFree((char*)*pv);
+            pv++;
+        }
+        RTMemFree(m_ProxyOptions.nameservers);
+        m_ProxyOptions.nameservers = NULL;
     }
 }
 
@@ -1016,10 +1028,7 @@ int VBoxNetLwipNAT::processFrame(void *pvFrame, size_t cbFrame)
 
     struct pbuf *p = pbuf_alloc(PBUF_RAW, (u16_t)cbFrame + ETH_PAD_SIZE, PBUF_POOL);
     if (RT_UNLIKELY(p == NULL))
-    {
-        LogRel2(("pbuf_alloc failed\n"));
         return VERR_NO_MEMORY;
-    }
 
     /*
      * The code below is inlined version of:
@@ -1206,12 +1215,16 @@ extern "C" DECLEXPORT(int) TrustedMain(int argc, char **argv, char **envp)
             int vrc = com::GetVBoxUserHomeDirectory(szHome, sizeof(szHome), false);
             if (RT_SUCCESS(vrc))
             {
+                closesocket(icmpsock4);
+                closesocket(icmpsock6);
                 return RTMsgErrorExit(RTEXITCODE_FAILURE,
                                       "Failed to initialize COM: %s: %Rhrf",
                                       szHome, hrc);
             }
         }
 #endif  // VBOX_WITH_XPCOM
+        closesocket(icmpsock4);
+        closesocket(icmpsock6);
         return RTMsgErrorExit(RTEXITCODE_FAILURE,
                               "Failed to initialize COM: %Rhrf", hrc);
     }
@@ -1311,7 +1324,6 @@ static int vboxNetNATLogInit(int argc, char **argv)
     if (cch >= sizeof(szEnvVarBase))
         return VERR_BUFFER_OVERFLOW;
 
-    char szError[RTPATH_MAX + 128];
     rc = com::VBoxLogRelCreate("NAT Network",
                                szLogFile,
                                RTLOGFLAGS_PREFIX_TIME_PROG,
@@ -1322,7 +1334,28 @@ static int vboxNetNATLogInit(int argc, char **argv)
                                0 /* cHistory */,
                                0 /* uHistoryFileTime */,
                                0 /* uHistoryFileSize */,
-                               szError, sizeof(szError));
+                               NULL /*pErrInfo*/);
+
+    /*
+     * Provide immediate feedback if corresponding LogRel level is
+     * enabled.  It's frustrating when you chase some rare event and
+     * discover you didn't actually have the corresponding log level
+     * enabled because of a typo in the environment variable name or
+     * its content.
+     */
+#define LOG_PING(_log) _log((#_log " enabled\n"))
+    LOG_PING(LogRel2);
+    LOG_PING(LogRel3);
+    LOG_PING(LogRel4);
+    LOG_PING(LogRel5);
+    LOG_PING(LogRel6);
+    LOG_PING(LogRel7);
+    LOG_PING(LogRel8);
+    LOG_PING(LogRel9);
+    LOG_PING(LogRel10);
+    LOG_PING(LogRel11);
+    LOG_PING(LogRel12);
+
     return rc;
 }
 
